@@ -55,6 +55,6 @@ function newuser_wiz_compose_redirect() {
 
 function newuser_wiz_version() {
 
-   return '1.3';
+   return '1.3.1';
 
 }
